@@ -44,13 +44,13 @@
 #' run_multiple(model_sir, ndays = 100, nsims = 50, saver = saver, nthreads = 2)
 #'
 #' # Retrieving the results
-#' ans <- run_multiple_get_results(model_sir)
+#' ans <- run_multiple_get_results(model_sir, nthreads = 2)
 #'
 #' head(ans$total_hist)
 #' head(ans$reproductive)
 #'
 #' # Plotting
-#' multi_sir <- run_multiple_get_results(model_sir)$total_hist
+#' multi_sir <- ans$total_hist
 #' multi_sir <- multi_sir[multi_sir$date <= 20, ]
 #' plot(multi_sir)
 #'
@@ -110,11 +110,16 @@ run_multiple.epiworld_model <- function(
 
 #' @export
 #' @rdname run_multiple
+#' @param nthreads Integer. Number of threads (passed to [parallel::makeCluster()]).
 #' @returns
 #' - The `run_multiple_get_results` function returns a named list with the
 #' data specified by `make_saver`.
 #' @importFrom utils read.table
-run_multiple_get_results <- function(m) {
+#' @importFrom parallel parLapply makeCluster stopCluster detectCores
+run_multiple_get_results <- function(
+    m,
+    nthreads = parallel::detectCores() - 1L
+    ) {
 
   if (!inherits(m, "epiworld_model"))
     stop("-m- must be of class `epiworld_model`.")
@@ -128,6 +133,8 @@ run_multiple_get_results <- function(m) {
   output <- vector("list", length(saver$what))
   names(output) <- saver$what
 
+  cl <- parallel::makeCluster(nthreads)
+  on.exit(parallel::stopCluster(cl))
   for (i in saver$what) {
     # Listing the files
     fnames <- list.files(
@@ -137,10 +144,13 @@ run_multiple_get_results <- function(m) {
     )
 
     # Reading the files
-    output[[i]] <- lapply(fnames, utils::read.table, sep = " ", header = TRUE)
+    output[[i]] <- parallel::parLapply(
+      cl, fnames, utils::read.table, sep = " ", header = TRUE,
+      comment.char = ""
+    )
 
     # Getting number of simulation
-    output[[i]] <- lapply(seq_along(fnames), function(j) {
+    output[[i]] <- lapply(seq_along(fnames), \(j) {
       if (nrow(output[[i]][[j]]) > 0)
         cbind(sim_num = j, output[[i]][[j]])
       else
@@ -335,10 +345,10 @@ make_saver <- function(
 print.epiworld_saver <- function(x, ...) {
 
   cat("A saver for -run_multiple-\n")
-  cat("Saves the following:", paste(x$what, sep = ", "), "\n")
-  cat("To file            :", ifelse(x$file_output, "yes", "no"), "\n")
-  if (x$file_output)
-    cat("Saver pattern      :", x$fn)
+  cat("Saves the following :", paste(x$what, sep = ", "), "\n")
+  cat("To file             :", ifelse(x$file_output, "yes", "no"), "\n")
+  cat("Saver folder        :", dirname(x$fn), "\n")
+  cat("Saver id            :", x$id, "\n")
 
   invisible(x)
 
