@@ -285,9 +285,9 @@ public:
      * - Date when the source was infected
      */
     ///@{
-    MapVec_type<int,int> reproductive_number() const;
+    MapVec_type<int,int> get_reproductive_number() const;
 
-    void reproductive_number(
+    void get_reproductive_number(
         std::string fn
         ) const;
     ///@}
@@ -305,7 +305,7 @@ public:
      * (when normalized).
      * @return std::vector< epiworld_double > 
      */
-    std::vector< epiworld_double > transition_probability(
+    std::vector< epiworld_double > get_transition_probability(
         bool print = true,
         bool normalize = true
     ) const;
@@ -322,14 +322,14 @@ public:
      * the infection of the target.
     */
    ///@{
-    void generation_time(
+    void get_generation_time(
         std::vector< int > & agent_id,
         std::vector< int > & virus_id,
         std::vector< int > & time,
         std::vector< int > & gentime
     ) const; ///< Get the generation time
 
-    void generation_time(
+    void get_generation_time(
         std::string fn
     ) const; ///< Write the generation time to a file
     ///@}
