@@ -60,7 +60,7 @@ private:
 
     epiworld_fast_int queue_init    = Queue<TSeq>::Everyone; ///< Change of state when added to agent.
     epiworld_fast_int queue_post    = -Queue<TSeq>::Everyone; ///< Change of state when removed from agent.
-    epiworld_fast_int queue_removed = -99; ///< Change of state when agent is removed
+    epiworld_fast_int queue_removed = -Queue<TSeq>::Everyone; ///< Change of state when agent is removed
 
     std::shared_ptr< VirusFunctions<TSeq> > virus_functions = 
         std::make_shared< VirusFunctions<TSeq> >();
